@@ -1,55 +1,72 @@
-#!/usr/bin/env python
+#
+# py_sline_data.py
+#
+# Mon May 22 16:00:00 2023
+# Copyright  2023  Sandro Dias Pinto Vitenti
+# <vitenti@uel.br>
+#
+# py_sline_data.py
+# Copyright (C) 2023 Sandro Dias Pinto Vitenti <vitenti@uel.br>
+#
+# numcosmo is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# numcosmo is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along
+# with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Example of a Data class for the SLine model."""
 
-import math
-from scipy.stats import norm
 import numpy as np
 
-try:
-    import gi
-
-    gi.require_version('NumCosmo', '1.0')
-    gi.require_version('NumCosmoMath', '1.0')
-except:
-    pass
-
-from gi.repository import GObject
-from gi.repository import NumCosmo as Nc
-from gi.repository import NumCosmoMath as Ncm
-
 from py_sline_model import PySLineModel
 
+from numcosmo_py import Ncm, GObject
+
 
 #
 # Creating a new class implementing our object Ncm.Data
 #
 class PySLineData(Ncm.Data):
+    """A simple data class for the SLine model."""
+
     #
     # Creating three properties, len (length), dof (degrees of freedom) and data (NcmMatrix containing
     # the data).
     #
-    len = GObject.Property(type=GObject.TYPE_UINT, default=0, flags=GObject.PARAM_READWRITE)
-    dof = GObject.Property(type=GObject.TYPE_UINT, default=0, flags=GObject.PARAM_READWRITE)
+    len = GObject.Property(
+        type=GObject.TYPE_UINT, default=0, flags=GObject.PARAM_READWRITE  # type: ignore
+    )
+    dof = GObject.Property(
+        type=GObject.TYPE_UINT, default=0, flags=GObject.PARAM_READWRITE  # type: ignore
+    )
     data = GObject.Property(type=Ncm.Matrix, flags=GObject.PARAM_READWRITE)
 
     #
     # The contructor assigns some default values and calls the father's constructor.
     #
-    def __init__(self, len=600):
+    def __init__(self, length=600):
         Ncm.Data.__init__(self)
-        self.len = len
+        self.len = length
         self.dof = self.len - 2
         self.data = Ncm.Matrix.new(self.len, 3)
 
     #
     # Implements the virtual method get_length.
     #
-    def do_get_length(self):
+    def do_get_length(self) -> int:  # pylint: disable-msg=arguments-differ
         return self.len
 
     #
     # Implements the virtual method get_dof.
     #
-    def do_get_dof(self):
+    def do_get_dof(self) -> int:  # pylint: disable-msg=arguments-differ
         return self.dof
 
     #
@@ -59,7 +76,7 @@ class PySLineData(Ncm.Data):
     # involves the decomposition of a constant matrix, it can be done
     # during `begin' once and then used afterwards.
     #
-    def do_begin(self):
+    def do_begin(self):  # pylint: disable-msg=arguments-differ
         return
 
     #
@@ -67,9 +84,8 @@ class PySLineData(Ncm.Data):
     # This method should do all the necessary calculations using mset
     # to be able to calculate the likelihood afterwards.
     #
-    def do_prepare(self, mset):
+    def do_prepare(self, mset):  # pylint: disable-msg=arguments-differ
         self.dof = self.len - mset.fparams_len()
-        return
 
     #
     # Implements the virtual method `resample'.
@@ -77,13 +93,14 @@ class PySLineData(Ncm.Data):
     # It is necessary to the MC analysis but can be skipped if
     # doing only MCMC.
     #
-    def do_resample(self, mset, rng):
+    def do_resample(self, mset, rng):  # pylint: disable-msg=arguments-differ
         mid = mset.get_id_by_ns("NcPySLineModel")
         slm = mset.peek(mid)
+        assert isinstance(slm, PySLineModel)
 
         my_data = []
 
-        for i in range(self.len):
+        for _ in range(self.len):
             x = rng.uniform_gen(0.0, 10.0)
             s = x * rng.uniform_gen(0.4, 0.5)
             v = rng.gaussian_gen(slm.f_x(x), s)
@@ -99,9 +116,10 @@ class PySLineData(Ncm.Data):
     # This method should calculate the value of the likelihood for
     # the model set `mset'.
     #
-    def do_m2lnL_val(self, mset):
+    def do_m2lnL_val(self, mset):  # pylint: disable-msg=arguments-differ
         mid = mset.get_id_by_ns("NcPySLineModel")
         slm = mset.peek(mid)
+        assert isinstance(slm, PySLineModel)
 
         m2lnL = 0.0
         for i in range(self.len):
