@@ -4,13 +4,14 @@
  *            nc_galaxy_wl_dist.h
  *
  *  Mon July 27 11:13:56 2020
- *  Copyright  2020  Sandro Dias Pinto Vitenti & Mariana Penna Lima
- *  <vitenti@uel.br>, <pennalima@gmail.com>
+ *  Copyright  2023  Sandro Dias Pinto Vitenti & Mariana Penna Lima & Caio Lima de Oliveira
+ *  <vitenti@uel.br>, <pennalima@gmail.com>, <caiolimadeoliveira@pm.me>
  ****************************************************************************/
 /*
  * nc_galaxy_wl_dist.h
- * Copyright (C) 2020 Sandro Dias Pinto Vitenti <vitenti@uel.br>
- * Copyright (C) 2020 Mariana Penna Lima <pennalima@gmail.com>
+ * Copyright (C) 2023 Sandro Dias Pinto Vitenti <vitenti@uel.br>
+ * Copyright (C) 2023 Mariana Penna Lima <pennalima@gmail.com>
+ * Copyright (C) 2023 Caio Lima de Oliveira <caiolimadeoliveira@pm.me>
  *
  * numcosmo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -35,6 +36,7 @@
 #include <numcosmo/math/ncm_rng.h>
 #include <numcosmo/lss/nc_halo_density_profile.h>
 #include <numcosmo/lss/nc_wl_surface_mass_density.h>
+#include <numcosmo/lss/nc_galaxy_redshift.h>
 
 G_BEGIN_DECLS
 
@@ -53,7 +55,8 @@ struct _NcGalaxyWLDistClass
 {
   /*< private >*/
   GObjectClass parent_class;
-  
+
+  void (*m2lnP_initial_prep) (NcGalaxyWLDist *gwld, NcGalaxyRedshift *gz, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster);
   void (*m2lnP_prep) (NcGalaxyWLDist *gwld, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster, const guint gal_i);
   gdouble (*m2lnP) (NcGalaxyWLDist *gwld, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster, const guint gal_i, const gdouble z);
   gdouble (*gen) (NcGalaxyWLDist *gwld, const gdouble g_true, NcmRNG *rng);
@@ -74,6 +77,7 @@ NcGalaxyWLDist *nc_galaxy_wl_dist_ref (NcGalaxyWLDist *gwld);
 void nc_galaxy_wl_dist_free (NcGalaxyWLDist *gwld);
 void nc_galaxy_wl_dist_clear (NcGalaxyWLDist **gwld);
 
+NCM_INLINE void nc_galaxy_wl_dist_m2lnP_initial_prep (NcGalaxyWLDist *gwld, NcGalaxyRedshift *gz, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster);
 NCM_INLINE void nc_galaxy_wl_dist_m2lnP_prep (NcGalaxyWLDist *gwld, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster, const guint gal_i);
 NCM_INLINE gdouble nc_galaxy_wl_dist_m2lnP (NcGalaxyWLDist *gwld, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster, const guint gal_i, const gdouble z);
 NCM_INLINE gdouble nc_galaxy_wl_dist_gen (NcGalaxyWLDist *gwld, const gdouble g_true, NcmRNG *rng);
@@ -90,13 +94,22 @@ G_END_DECLS
 
 G_BEGIN_DECLS
 
+NCM_INLINE void
+nc_galaxy_wl_dist_m2lnP_initial_prep (NcGalaxyWLDist *gwld, NcGalaxyRedshift *gz, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster)
+{
+  NcGalaxyWLDistClass *gwld_class = NC_GALAXY_WL_DIST_GET_CLASS (gwld);
+
+  if (gwld_class->m2lnP_initial_prep != NULL)
+    NC_GALAXY_WL_DIST_GET_CLASS (gwld)->m2lnP_initial_prep (gwld, gz, cosmo, dp, smd, z_cluster);
+}
+
 NCM_INLINE void
 nc_galaxy_wl_dist_m2lnP_prep (NcGalaxyWLDist *gwld, NcHICosmo *cosmo, NcHaloDensityProfile *dp, NcWLSurfaceMassDensity *smd, const gdouble z_cluster, const guint gal_i)
 {
   NcGalaxyWLDistClass *gwld_class = NC_GALAXY_WL_DIST_GET_CLASS (gwld);
-  
+
   if (gwld_class->m2lnP_prep != NULL)
-    return NC_GALAXY_WL_DIST_GET_CLASS (gwld)->m2lnP_prep (gwld, cosmo, dp, smd, z_cluster, gal_i);
+    NC_GALAXY_WL_DIST_GET_CLASS (gwld)->m2lnP_prep (gwld, cosmo, dp, smd, z_cluster, gal_i);
 }
 
 NCM_INLINE gdouble
