@@ -1,3 +1,4 @@
+/* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*-  */
 /***************************************************************************
  *            ncm_c.h
  *
@@ -38,29 +39,8 @@
 
 G_BEGIN_DECLS
 
-#define NCM_TYPE_C             (ncm_c_get_type ())
-#define NCM_C(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_C, NcmC))
-#define NCM_C_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_C, NcmCClass))
-#define NCM_IS_C(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_C))
-#define NCM_IS_C_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_C))
-#define NCM_C_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_C, NcmCClass))
-
-typedef struct _NcmCClass NcmCClass;
-typedef struct _NcmC NcmC;
-
-struct _NcmCClass
-{
-  /*< private >*/
-  GObjectClass parent_class;
-};
-
-struct _NcmC
-{
-  /*< private >*/
-  GObject parent_instance;
-};
-
-GType ncm_c_get_type (void) G_GNUC_CONST;
+#define NCM_TYPE_C (ncm_c_get_type ())
+G_DECLARE_FINAL_TYPE (NcmC, ncm_c, NCM, C, GObject)
 
 /*******************************************************************************
  * Mathematical constants
@@ -769,7 +749,7 @@ ncm_c_H_bind (const gdouble n, const gdouble j)
   const gdouble f_nj_m_one  = -ncm_util_sqrt1px_m1 (f_arg) / sqrt (1.0 + f_arg); /*(1.0 - sqrt (1.0 + f_arg))*/
   const gdouble r           = ncm_c_mass_ratio_e_p ();
   const gdouble E_binding   = ncm_c_H_reduced_energy () * f_nj_m_one * (1.0 - 0.5 * f_nj_m_one * r / gsl_pow_2 (1.0 + r));
-  
+
   return -E_binding;
 }
 
