@@ -14,12 +14,12 @@
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * numcosmo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
@@ -35,30 +35,8 @@
 G_BEGIN_DECLS
 
 #define NCM_TYPE_DATA_ROSENBROCK             (ncm_data_rosenbrock_get_type ())
-#define NCM_DATA_ROSENBROCK(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), NCM_TYPE_DATA_ROSENBROCK, NcmDataRosenbrock))
-#define NCM_DATA_ROSENBROCK_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), NCM_TYPE_DATA_ROSENBROCK, NcmDataRosenbrockClass))
-#define NCM_IS_DATA_ROSENBROCK(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NCM_TYPE_DATA_ROSENBROCK))
-#define NCM_IS_DATA_ROSENBROCK_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), NCM_TYPE_DATA_ROSENBROCK))
-#define NCM_DATA_ROSENBROCK_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), NCM_TYPE_DATA_ROSENBROCK, NcmDataRosenbrockClass))
 
-typedef struct _NcmDataRosenbrockClass NcmDataRosenbrockClass;
-typedef struct _NcmDataRosenbrock NcmDataRosenbrock;
-typedef struct _NcmDataRosenbrockPrivate NcmDataRosenbrockPrivate;
-
-struct _NcmDataRosenbrockClass
-{
-  /*< private >*/
-  NcmDataClass parent_class;
-};
-
-struct _NcmDataRosenbrock
-{
-  /*< private >*/
-  NcmData parent_instance;
-  NcmDataRosenbrockPrivate *priv;
-};
-
-GType ncm_data_rosenbrock_get_type (void) G_GNUC_CONST;
+G_DECLARE_FINAL_TYPE (NcmDataRosenbrock, ncm_data_rosenbrock, NCM, DATA_ROSENBROCK, NcmData)
 
 NcmDataRosenbrock *ncm_data_rosenbrock_new (void);
 NcmDataRosenbrock *ncm_data_rosenbrock_ref (NcmDataRosenbrock *drb);
@@ -68,3 +46,4 @@ void ncm_data_rosenbrock_clear (NcmDataRosenbrock **drb);
 G_END_DECLS
 
 #endif /* _NCM_DATA_ROSENBROCK_H_ */
+
