@@ -35,14 +35,14 @@
  * the virtual methods of the #NcmStatsDistKernel class. For more information, check the documentation of #NcmStatsDistKernel.
  * Below, there are some definitions of the multivariate Gaussian distribution. For more information, check  [[On Sampling from the Multivariate t Distribution, Marius Hofert](https://journal.r-project.org/archive/2013/RJ-2013-033/RJ-2013-033.pdf)].
  *
- * The multivariate Normal distribution has its stochastic representation as 
+ * The multivariate Normal distribution has its stochastic representation as
  * \begin{align}
  * \textbf{X} &= \mu + A \textbf{Z}
  * ,\end{align}
  * where $\textbf{Z}= (Z_1,Z_2,...,Z_n)$ is a $n$-dimension random vector whose components are independent normal random variables.
  * $A$ is a $d \times n$ matrix and $\mu$ is a $d$-dimensional random vector that defines the mean of the distribution. The covariance
  * matrix is defined as $\Sigma =  AA^T$, such that the distribtuion of $\textbf{X}$ is uniquely defined by its covariance matrix and the
- * mean vector, that is,$ \textbf{X} \sim N(\mu, \Sigma)$. 
+ * mean vector, that is,$ \textbf{X} \sim N(\mu, \Sigma)$.
  *
  * Assuming that $n=d$, the probability density function (pdf) of $\textbf{X}$ is
  * \begin{align}
@@ -55,12 +55,12 @@
  * \Sigma = LL^T
  * ,\end{align}
  * where $L$ is a triangular matrix with positive definite values. This decomposition can facilitate some computational calculations.
- * 
+ *
  * This object uses the pdf given by equation \eqref{pdf} to define a Gaussian kernel, such that it can generate points distributed
  * by multivariate Gaussian distributions. The normal distribution is easy to sample from and therefore is commonly used as a kernel.
- * 
- * The user must provide the following input value: @dim - ncm\_stats\_dist\_kernel\_gauss\_new(). Once this object is initialized, 
- * the user can use the methods in the #NcmStatsDistKernel class with this object. 
+ *
+ * The user must provide the following input value: @dim - ncm\_stats\_dist\_kernel\_gauss\_new(). Once this object is initialized,
+ * the user can use the methods in the #NcmStatsDistKernel class with this object.
  *
  **/
 
@@ -86,7 +86,7 @@
 
 struct _NcmStatsDistKernelGaussPrivate
 {
-  GArray *t_array;
+  gint place_holder;
 };
 
 enum
@@ -100,8 +100,8 @@ static void
 ncm_stats_dist_kernel_gauss_init (NcmStatsDistKernelGauss *sdkg)
 {
   NcmStatsDistKernelGaussPrivate * const self = sdkg->priv = ncm_stats_dist_kernel_gauss_get_instance_private (sdkg);
-  
-  self->t_array = g_array_new (FALSE, FALSE, sizeof (gdouble));
+
+  self->place_holder = 0;
 }
 
 static void
@@ -109,9 +109,9 @@ _ncm_stats_dist_kernel_gauss_set_property (GObject *object, guint prop_id, const
 {
   /*NcmStatsDistKernelGauss *sdkg = NCM_STATS_DIST_ND_KDE_GAUSS (object);*/
   /*NcmStatsDistKernelGaussPrivate * const self = sdkg->priv;*/
-  
+
   g_return_if_fail (NCM_IS_STATS_DIST_KERNEL_GAUSS (object));
-  
+
   switch (prop_id)
   {
     default:
@@ -125,9 +125,9 @@ _ncm_stats_dist_kernel_gauss_get_property (GObject *object, guint prop_id, GValu
 {
   /*NcmStatsDistKernelGauss *sdkg = NCM_STATS_DIST_ND_KDE_GAUSS (object);*/
   /*NcmStatsDistKernelGaussPrivate * const self = sdkg->priv;*/
-  
+
   g_return_if_fail (NCM_IS_STATS_DIST_KERNEL_GAUSS (object));
-  
+
   switch (prop_id)
   {
     default:
@@ -139,11 +139,9 @@ _ncm_stats_dist_kernel_gauss_get_property (GObject *object, guint prop_id, GValu
 static void
 _ncm_stats_dist_kernel_gauss_dispose (GObject *object)
 {
-  NcmStatsDistKernelGauss *sdkg               = NCM_STATS_DIST_KERNEL_GAUSS (object);
-  NcmStatsDistKernelGaussPrivate * const self = sdkg->priv;
-  
-  g_clear_pointer (&self->t_array, g_array_unref);
-  
+  /* NcmStatsDistKernelGauss *sdkg               = NCM_STATS_DIST_KERNEL_GAUSS (object); */
+  /* NcmStatsDistKernelGaussPrivate * const self = sdkg->priv; */
+
   /* Chain up : end */
   G_OBJECT_CLASS (ncm_stats_dist_kernel_gauss_parent_class)->dispose (object);
 }
@@ -159,8 +157,8 @@ static gdouble _ncm_stats_dist_kernel_gauss_get_rot_bandwidth (NcmStatsDistKerne
 static gdouble _ncm_stats_dist_kernel_gauss_get_lnnorm (NcmStatsDistKernel *sdk, NcmMatrix *cov_decomp);
 static gdouble _ncm_stats_dist_kernel_gauss_eval_unnorm (NcmStatsDistKernel *sdk, const gdouble chi2);
 static void _ncm_stats_dist_kernel_gauss_eval_unnorm_vec (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *Ku);
-static void _ncm_stats_dist_kernel_gauss_eval_sum0_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, NcmVector *lnnorms, gdouble *gamma, gdouble *lambda);
-static void _ncm_stats_dist_kernel_gauss_eval_sum1_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, gdouble lnnorm, gdouble *gamma, gdouble *lambda);
+static void _ncm_stats_dist_kernel_gauss_eval_sum0_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, NcmVector *lnnorms, NcmVector *lnK, gdouble *gamma, gdouble *lambda);
+static void _ncm_stats_dist_kernel_gauss_eval_sum1_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, gdouble lnnorm, NcmVector *lnK, gdouble *gamma, gdouble *lambda);
 static void _ncm_stats_dist_kernel_gauss_sample (NcmStatsDistKernel *sdk, NcmMatrix *cov_decomp, const gdouble href, NcmVector *mu, NcmVector *x, NcmRNG *rng);
 
 static void
@@ -168,12 +166,12 @@ ncm_stats_dist_kernel_gauss_class_init (NcmStatsDistKernelGaussClass *klass)
 {
   GObjectClass *object_class         = G_OBJECT_CLASS (klass);
   NcmStatsDistKernelClass *sdk_class = NCM_STATS_DIST_KERNEL_CLASS (klass);
-  
+
   object_class->set_property = &_ncm_stats_dist_kernel_gauss_set_property;
   object_class->get_property = &_ncm_stats_dist_kernel_gauss_get_property;
   object_class->dispose      = &_ncm_stats_dist_kernel_gauss_dispose;
   object_class->finalize     = &_ncm_stats_dist_kernel_gauss_finalize;
-  
+
   sdk_class->get_rot_bandwidth      = &_ncm_stats_dist_kernel_gauss_get_rot_bandwidth;
   sdk_class->get_lnnorm             = &_ncm_stats_dist_kernel_gauss_get_lnnorm;
   sdk_class->eval_unnorm            = &_ncm_stats_dist_kernel_gauss_eval_unnorm;
@@ -195,7 +193,7 @@ static gdouble
 _ncm_stats_dist_kernel_gauss_get_lnnorm (NcmStatsDistKernel *sdk, NcmMatrix *cov_decomp)
 {
   NcmStatsDistKernelPrivate * const pself = sdk->priv;
-  
+
   return 0.5 * (pself->d * ncm_c_ln2pi () + ncm_matrix_cholesky_lndet (cov_decomp));
 }
 
@@ -211,16 +209,16 @@ _ncm_stats_dist_kernel_gauss_eval_unnorm_vec (NcmStatsDistKernel *sdk, NcmVector
   /*NcmStatsDistKernelPrivate * const pself = sdk->priv;*/
   const guint n = ncm_vector_len (chi2);
   gint i;
-  
+
   g_assert (ncm_vector_len (Ku) == n);
-  
+
   if ((ncm_vector_stride (Ku) == 1) && (ncm_vector_stride (chi2) == 1))
   {
     for (i = 0; i < n; i++)
     {
       const gdouble chi2_i = ncm_vector_fast_get (chi2, i);
       const gdouble Ku_i   = _ncm_stats_dist_kernel_gauss_eval_unnorm (sdk, chi2_i);
-      
+
       ncm_vector_fast_set (Ku, i, Ku_i);
     }
   }
@@ -230,98 +228,98 @@ _ncm_stats_dist_kernel_gauss_eval_unnorm_vec (NcmStatsDistKernel *sdk, NcmVector
     {
       const gdouble chi2_i = ncm_vector_get (chi2, i);
       const gdouble Ku_i   = _ncm_stats_dist_kernel_gauss_eval_unnorm (sdk, chi2_i);
-      
+
       ncm_vector_set (Ku, i, Ku_i);
     }
   }
 }
 
 static void
-_ncm_stats_dist_kernel_gauss_eval_sum0_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, NcmVector *lnnorms, gdouble *gamma, gdouble *lambda)
+_ncm_stats_dist_kernel_gauss_eval_sum0_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, NcmVector *lnnorms, NcmVector *lnK, gdouble *gamma, gdouble *lambda)
 {
-  NcmStatsDistKernelGaussPrivate * const self = NCM_STATS_DIST_KERNEL_GAUSS (sdk)->priv;
+  /* NcmStatsDistKernelGaussPrivate * const self = NCM_STATS_DIST_KERNEL_GAUSS (sdk)->priv; */
   /*NcmStatsDistKernelPrivate * const pself  = sdk->priv;*/
-  
+
   const guint n = ncm_vector_len (chi2);
   gdouble lnt_max = GSL_NEGINF;
   gint i, i_max = -1;
-  
+
   g_assert (n == ncm_vector_len (weights));
   g_assert (n == ncm_vector_len (lnnorms));
+  g_assert (n == ncm_vector_len (lnK));
   g_assert (1 == ncm_vector_stride (chi2));
   g_assert (1 == ncm_vector_stride (weights));
   g_assert (1 == ncm_vector_stride (lnnorms));
-  
-  g_array_set_size (self->t_array, n);
-  
+  g_assert (1 == ncm_vector_stride (lnK));
+
   for (i = 0; i < n; i++)
   {
     const gdouble chi2_i = ncm_vector_fast_get (chi2, i);
     const gdouble w_i    = ncm_vector_fast_get (weights, i);
     const gdouble lnu_i  = ncm_vector_fast_get (lnnorms, i);
-    
+
     const gdouble lnt_i = -0.5 * chi2_i - lnu_i + log (w_i);
-    
+
     if (lnt_i > lnt_max)
     {
       i_max   = i;
       lnt_max = lnt_i;
     }
-    
-    g_array_index (self->t_array, gdouble, i) = lnt_i;
+
+    ncm_vector_fast_set (lnK, i, lnt_i);
   }
-  
+
   lambda[0] = 0.0;
-  
+
   for (i = 0; i < i_max; i++)
-    lambda[0] += exp (g_array_index (self->t_array, gdouble, i) - lnt_max);
-  
+    lambda[0] += exp (ncm_vector_fast_get (lnK, i) - lnt_max);
+
   for (i = i_max + 1; i < n; i++)
-    lambda[0] += exp (g_array_index (self->t_array, gdouble, i) - lnt_max);
-  
+    lambda[0] += exp (ncm_vector_fast_get (lnK, i) - lnt_max);
+
   gamma[0] = lnt_max;
 }
 
 static void
-_ncm_stats_dist_kernel_gauss_eval_sum1_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, gdouble lnnorm, gdouble *gamma, gdouble *lambda)
+_ncm_stats_dist_kernel_gauss_eval_sum1_gamma_lambda (NcmStatsDistKernel *sdk, NcmVector *chi2, NcmVector *weights, gdouble lnnorm, NcmVector *lnK, gdouble *gamma, gdouble *lambda)
 {
-  NcmStatsDistKernelGaussPrivate * const self = NCM_STATS_DIST_KERNEL_GAUSS (sdk)->priv;
-  /*NcmStatsDistKernelPrivate * const pself  = sdk->priv;*/
-  
+  /* NcmStatsDistKernelGaussPrivate * const self = NCM_STATS_DIST_KERNEL_GAUSS (sdk)->priv; */
+  /* NcmStatsDistKernelPrivate * const pself  = sdk->priv; */
+
   const guint n = ncm_vector_len (chi2);
   gdouble lnt_max = GSL_NEGINF;
   gint i, i_max = -1;
-  
+
   g_assert (n == ncm_vector_len (weights));
+  g_assert (n == ncm_vector_len (lnK));
   g_assert (1 == ncm_vector_stride (chi2));
   g_assert (1 == ncm_vector_stride (weights));
-  
-  g_array_set_size (self->t_array, n);
-  
+  g_assert (1 == ncm_vector_stride (lnK));
+
   for (i = 0; i < n; i++)
   {
     const gdouble chi2_i = ncm_vector_fast_get (chi2, i);
     const gdouble w_i    = ncm_vector_fast_get (weights, i);
-    
+
     const gdouble lnt_i = -0.5 * chi2_i + log (w_i);
-    
+
     if (lnt_i > lnt_max)
     {
       i_max   = i;
       lnt_max = lnt_i;
     }
-    
-    g_array_index (self->t_array, gdouble, i) = lnt_i;
+
+    ncm_vector_fast_set (lnK, i, lnt_i);
   }
-  
+
   lambda[0] = 0.0;
-  
+
   for (i = 0; i < i_max; i++)
-    lambda[0] += exp (g_array_index (self->t_array, gdouble, i) - lnt_max);
-  
+    lambda[0] += exp (ncm_vector_fast_get (lnK, i) - lnt_max);
+
   for (i = i_max + 1; i < n; i++)
-    lambda[0] += exp (g_array_index (self->t_array, gdouble, i) - lnt_max);
-  
+    lambda[0] += exp (ncm_vector_fast_get (lnK, i) - lnt_max);
+
   gamma[0] = lnt_max - lnnorm;
 }
 
@@ -330,14 +328,14 @@ _ncm_stats_dist_kernel_gauss_sample (NcmStatsDistKernel *sdk, NcmMatrix *cov_dec
 {
   NcmStatsDistKernelPrivate * const pself = sdk->priv;
   gint i, ret;
-  
+
   for (i = 0; i < pself->d; i++)
   {
     const gdouble u_i = gsl_ran_ugaussian (rng->r);
-    
+
     ncm_vector_set (x, i, u_i * href);
   }
-  
+
   /* CblasLower, CblasNoTrans => CblasUpper, CblasTrans */
   ret = gsl_blas_dtrmv (CblasUpper, CblasTrans, CblasNonUnit,
                         ncm_matrix_gsl (cov_decomp), ncm_vector_gsl (x));
@@ -360,7 +358,7 @@ ncm_stats_dist_kernel_gauss_new (const guint dim)
   NcmStatsDistKernelGauss *sdkg = g_object_new (NCM_TYPE_STATS_DIST_KERNEL_GAUSS,
                                                 "dimension", dim,
                                                 NULL);
-  
+
   return sdkg;
 }
 
